from pantomath_sdk import SqlView, PlatformTypes


def test_sql_view_good():
    test_node = SqlView(
        host="host",
        port=42,
        database="database",
        schema="Schema",
        name="SqlView Unit Test",
    )
    assert test_node.get_name() == "SqlView Unit Test"
    assert test_node.get_type() == "SQL_VIEW"
    assert (
        test_node.get_fully_qualified_object_name()
        == "host:42.database.Schema.SqlView Unit Test"
    )
    assert test_node.get_platform_type() == PlatformTypes.SQL_SERVER.value



from pantomath_sdk.model.dataset.dataset import DataSet
from pantomath_sdk.enums.dataset_type import DataSetTypes
from pantomath_sdk.enums.platform_types import PlatformTypes


class PowerBiDataFlowEntity(DataSet):
    """PowerBiDataFlowEntity's DataSet Class used for getting the required infomation for Pantomath
    :param group_id: The ID of the DataFlow's Group
    :type group_id: str
    :param object_id: The ID of the DataFlow
    :type object_id: str
    :param name: The name of the DataFlow
    :type name: str
    ...
    """

    def __init__(self, group_id, object_id, name):
        """Constructor method"""
        self._group_id = group_id
        self._object_id = object_id
        self._name = name

    @staticmethod
    def create(group_id, object_id, name):
        """Static method for obtaining PowerBiDataFlowEntity's DataSet Class
        used for getting the required infomation for Pantomath
        :param group_id: The ID of the DataFlow's Group
        :type group_id: str
        :param object_id: The ID of the DataFlow
        :type object_id: str
        :param name: The name of the DataFlow
        :type name: str
        ...
        :return: PowerBiDataFlowEntity class object
        :rtype: PowerBiDataFlowEntity
        """
        return PowerBiDataFlowEntity(group_id, object_id, name)

    def get_name(self):
        """Returns the name of the object
        ...
        :return: the name of the object
        :rtype: str
        """
        return self._name

    def get_type(self):
        """Returns the type of the object
        ...
        :return: the type of the object
        :rtype: str
        """
        return DataSetTypes.POWER_BI_DATAFLOW_ENTITY.value

    def get_fully_qualified_object_name(self):
        """Returns the Fully Qualified Name of the object
        ...
        :return: the Fully Qualified Name of the object
        :rtype: str
        """
        fqn = str(
            "app.powerbi.com/groups/"
            + str(self._group_id)
            + "/dataflows/"
            + str(self._object_id)
            + "/syntheticEntity/"
            + self._name
        ).lower()
        return fqn

    def get_platform_type(self):
        """Returns the platform type of the object
        ...
        :return: the platform type of the object
        :rtype: str
        """
        return PlatformTypes.POWERBI.value



from typing import Union, List
from pantomath_sdk.model.asset_path.asset_path import Asset, AssetPath
from pantomath_sdk.model.job.job import Job
from pantomath_sdk.enums.job_type import JobTypes
from pantomath_sdk.enums.platform_types import PlatformTypes


class DBTJobConstructor(Job):
    """DBTJobConstructor's Job Class used for getting the required information for Pantomath
    :param name: Name of the Job
    :type name: str
    :param host: Host for the account, e.g. cloud.getdbt.com or ACCOUNT_PREFIX.us2.dbt.com
    :type host: str
    :param account_id: ID of the Account
    :type account_id: str
    :param job_id: ID of the Project
    :type job_id: str
    :param project_name: Name of the Project
    :type project_name: str
    ...
    """

    def __init__(
        self,
        name,
        host,
        account_id,
        job_id,
        project_name,
        assets: Union[List[Asset], None] = None,
    ):
        """Constructor method"""
        self._name = name
        self._host = host
        self._account_id = account_id
        self._job_id = job_id
        self._project_name = project_name
        self._asset_path = AssetPath(
            platform_type=self.get_platform_type(),
            connection_name=self._project_name,
            assets=assets,
        )

    @staticmethod
    def create(
        name,
        host,
        account_id,
        job_id,
        project_name,
        assets: Union[List[Asset], None] = None,
    ):
        """Static method for obtaining DBTJobConstructor's DataSet Class
        used for getting the required information for Pantomath
        :param name: Name of the Job
        :type name: str
        :param host: Host for the account, e.g. cloud.getdbt.com or ACCOUNT_PREFIX.us2.dbt.com
        :type host: str
        :param account_id: ID of the Account
        :type account_id: str
        :param job_id: ID of the Project
        :type job_id: str
        :param project_name: Name of the Project
        :type project_name: str
        """
        return DBTJobConstructor(name, host, account_id, job_id, project_name, assets)

    def get_name(self):
        """Returns the name of the object
        ...
        :return: the name of the object
        :rtype: str
        """
        return self._name

    def get_type(self):
        """Returns the type of the object
        ...
        :return: the type of the object
        :rtype: str
        """
        return JobTypes.JOB.value

    def get_platform_type(self):
        """Returns the platform type of the object
        ...
        :return: the platform type of the object
        :rtype: str
        """
        return PlatformTypes.DBT.value

    def get_fully_qualified_object_name(self):
        """Returns the Fully Qualified Name of the object
        ...
        :return: the Fully Qualified Name of the object
        :rtype: str
        """
        return str(
            str(self._host)
            + "/#/accounts/"
            + str(self._account_id)
            + "."
            + str(self._project_name)
            + "."
            + str(self._name)
            + "."
            + str(self._job_id)
        ).lower()

    def get_asset_path(self) -> AssetPath:
        """Returns the Asset Path of the object
        ...
        :return: the Asset Path of the object
        :rtype: AssetPath
        """
        return self._asset_path



from typing import Union, List
from pantomath_sdk.model.asset_path.asset_path import Asset, AssetPath
from pantomath_sdk.model.job.job import Job
from pantomath_sdk.enums.job_type import JobTypes
from pantomath_sdk.enums.platform_types import PlatformTypes
import pantomath_sdk.util as util


class DataikuRecipe(Job):
    """DataikuRecipe's Job Class used for getting the required infomation for Pantomath
    :param _host_name: Dataiku Host
    :type _host_name: str
    :param project_key: Project ID
    :type project_key: str
    :param recipe_name: Recipe name
    :type recipe_name: str
    ...
    """

    def __init__(
        self,
        host_name,
        project_key,
        recipe_name,
        assets: Union[List[Asset], None] = None,
    ):
        """Constructor method"""
        self._host_name = host_name
        self._project_key = project_key
        self._recipe_name = recipe_name
        self._asset_path = AssetPath(
            platform_type=PlatformTypes.DATAIKU.value,
            connection_name=host_name,
            assets=assets,
        )

    @staticmethod
    def create(
        host_name, project_key, recipe_name, assets: Union[List[Asset], None] = None
    ):
        """Static method for obtaining DataikuRecipe's DataSet Class
        used for getting the required infomation for Pantomath
        :param _host_name: Dataiku Host
        :type _host_name: str
        :param project_key: Project ID
        :type project_key: str
        :param recipe_name: Recipe name
        :type recipe_name: str
        :return: DataikuRecipe class object
        :rtype: DataikuRecipe
        """
        return DataikuRecipe(host_name, project_key, recipe_name, assets)

    def get_name(self):
        """Returns the name of the object
        ...
        :return: the name of the object
        :rtype: str
        """
        return self._recipe_name

    def get_type(self):
        """Returns the type of the object
        ...
        :return: the type of the object
        :rtype: str
        """
        return JobTypes.RECIPE.value

    def get_fully_qualified_object_name(self):
        """Returns the Fully Qualified Name of the object
        ...
        :return: the Fully Qualified Name of the object
        :rtype: str
        """
        return util.sanitize_fully_qualified_object_name(
            util.normalize_host(
                str(
                    str(self._host_name)
                    + "/projects/"
                    + str(self._project_key)
                    + "/recipes/$"
                    + str(self._recipe_name)
                )
            )
        )

    def get_platform_type(self):
        """Returns the platform type of the object
        ...
        :return: the platform type of the object
        :rtype: str
        """
        return PlatformTypes.DATAIKU.value

    def get_asset_path(self) -> AssetPath:
        """Returns the Asset Path of the object
        ...
        :return: the Asset Path of the object
        :rtype: AssetPath
        """
        return self._asset_path



from pantomath_sdk import DBTModelConstructor, PlatformTypes, Asset


def test_dbt_model_good():
    node = DBTModelConstructor(
        host="cloud.getdbt.com",
        account_id=146523457734567,
        project_name="DBTModelConstructor Unit Test",
        model_name="DBTModelConstructor Unit Test Model",
    )
    assert node.get_name() == "DBTModelConstructor Unit Test Model"
    assert node.get_type() == "DBT_MODEL"
    assert (
        node.get_fully_qualified_object_name()
        == "cloud.getdbt.com/#/accounts/146523457734567/project/dbtmodelconstructor unit test/model/dbtmodelconstructor unit test model"
    )
    assert node.get_platform_type() == PlatformTypes.DBT.value
    assert (
        node.get_asset_path().__str__()
        == '[{"depth": 0, "name": "DBT", "type": "PLATFORM"}, {"depth": 1, "name": "Account Id - 146523457734567", "type": "CONNECTION"}]'
    )


def test_custom_dbt_model_asset_path_good():
    node = DBTModelConstructor(
        host="cloud.getdbt.com",
        account_id=146523457734567,
        project_name="DBTModelConstructor Unit Test",
        model_name="DBTModelConstructor Unit Test Model",
        assets=[
            Asset("Factory", "FACTORY"),
        ],
    )
    assert (
        node.get_asset_path().__str__()
        == '[{"depth": 0, "name": "DBT", "type": "PLATFORM"}, {"depth": 1, "name": "Account Id - 146523457734567", "type": "CONNECTION"}, {"depth": 2, "name": "Factory", "type": "FACTORY"}]'
    )



from pantomath_sdk import JobRunLog
import datetime


def test_job_run_log_get_functions():
    mock_data = {
        "job_run": "job_run",
        "status": "status",
        "message": "message",
        "records_effected": 42,
        "timestamp": datetime.datetime(2024, 7, 17, 19, 28, 26, 566012),
    }
    post_job_run_log = JobRunLog(**mock_data)
    assert post_job_run_log.get_unique_id() is not None
    assert post_job_run_log.get_job_run() == mock_data["job_run"]
    assert post_job_run_log.get_status() == mock_data["status"]
    assert post_job_run_log.get_message() == mock_data["message"]
    assert post_job_run_log.get_records_effected() == mock_data["records_effected"]
    assert post_job_run_log.get_timestamp() == "2024-07-17T19:28:26.566012Z"


def test_job_run_log_get_functions_no_optional_params():
    mock_data = {
        "job_run": "job_run",
        "status": "status",
        "timestamp": datetime.datetime(2024, 7, 17, 19, 28, 26, 566012),
    }
    post_job_run_log = JobRunLog(**mock_data)
    assert post_job_run_log.get_unique_id() is not None
    assert post_job_run_log.get_job_run() == mock_data["job_run"]
    assert post_job_run_log.get_status() == mock_data["status"]
    assert post_job_run_log.get_message() is None
    assert post_job_run_log.get_records_effected() is None
    assert post_job_run_log.get_timestamp() == "2024-07-17T19:28:26.566012Z"



from pantomath_sdk.model.dataset.dataset import DataSet
from pantomath_sdk.enums.dataset_type import DataSetTypes
import pantomath_sdk.util as util
from pantomath_sdk.enums.platform_types import PlatformTypes


class TableauDatasource(DataSet):
    """TableauDatasource's DataSet Class used for getting the required infomation for Pantomath
    :param host: The Tableau Host
    :type host: str
    :param uri: Tableau uri
    :type uri: str
    :param name: Name of the datasource
    :type name: str
    ...
    """

    def __init__(self, host, uri, name):
        """Constructor method"""
        self._host = host
        self._uri = uri
        self._name = name

    @staticmethod
    def create(host, uri, name):
        """Static method for obtaining TableauDatasource's DataSet Class
        used for getting the required infomation for Pantomath
        :param host: The Tableau Host
        :type host: str
        :param uri: Tableau uri
        :type uri: str
        :param name: Name of the datasource
        :type name: str
        ...
        :return: TableauDatasource class object
        :rtype: TableauDatasource
        """
        return TableauDatasource(host, uri, name)

    def get_name(self):
        """Returns the name of the object
        ...
        :return: the name of the object
        :rtype: str
        """
        return util.sanitize_tableau_string(self._name)

    def get_type(self):
        """Returns the type of the object
        ...
        :return: the type of the object
        :rtype: str
        """
        return DataSetTypes.TABLEAU_DATASOURCE.value

    def get_fully_qualified_object_name(self):
        """Returns the Fully Qualified Name of the object
        ...
        :return: the Fully Qualified Name of the object
        :rtype: str
        """
        return str(util.normalize_host(self._host) + "/" + self._uri).lower()

    def get_platform_type(self):
        """Returns the platform type of the object
        ...
        :return: the platform type of the object
        :rtype: str
        """
        return PlatformTypes.TABLEAU.value



from pantomath_sdk import PlatformTypes


def test_get_platform_types():
    expected_list = [
        "ADF",
        "AIRFLOW",
        "ALTERYX",
        "ANALYZER",
        "API_GATEWAY",
        "ASTRO",
        "ASTRONOMER",
        "AWS",
        "AWS_ATHENA",
        "AWS_EMR",
        "AWS_GLUE",
        "AWS_QUICKSIGHT",
        "AWS_SAGEMAKER",
        "AZSTORAGE",
        "BIGQUERY",
        "BIG_QUERY",
        "BOX",
        "CASSANDRADB",
        "CLICKHOUSE",
        "COMPOSER",
        "CONTROL_M",
        "CUSTOM_LOGS",
        "DATAIKU",
        "DATAPROC",
        "DATASTAGE",
        "DATA_ACTIVATOR",
        "DATA_PROC",
        "DBT",
        "DBT_CORE",
        "DBX",
        "DBX_LEGACY",
        "DELTA_LAKE",
        "DOMO",
        "DROPBOX",
        "DYNAMODB",
        "EXCEL",
        "EXTERNAL",
        "FIREBASE",
        "FIVETRAN",
        "GOOGLE_DATA_FUSION",
        "GOOGLE_DRIVE",
        "GOOGLE_LOOKER",
        "GOOGLE_STORAGE",
        "GREENPLUM",
        "HPCC",
        "HVR",
        "IBM_DATASTAGE",
        "INFORMATICA",
        "KAFKA",
        "KINESIS",
        "KNIME",
        "LOGIC_APP",
        "LOGIC_APPS",
        "MARIADB",
        "MATILLION",
        "METABASE",
        "MICROSOFT_FABRIC",
        "MICROSTRATEGY",
        "MODE",
        "MONGODB",
        "MYSQL",
        "NEO4J",
        "OBIEE",
        "ONELAKE",
        "ORACLE",
        "ORACLE_DATA_INTEGRATOR",
        "OUTLOOK",
        "PBIRS",
        "POSTGRES",
        "POWERBI",
        "POWER_APPS",
        "POWER_AUTOMATE",
        "PREFECT",
        "QLIKSENSE",
        "QLIKVIEW",
        "QLIK_REPLICATE",
        "RDS",
        "REDSHIFT",
        "S3",
        "SAP_BO",
        "SAP_HANA",
        "SHAREPOINT",
        "SIGMA",
        "SISENSE",
        "SNAP_LOGIC",
        "SNOWFLAKE",
        "SPARK",
        "SPOTFIRE",
        "SQL_SERVER",
        "SSAS",
        "SSIS",
        "SSRS",
        "STARBURST",
        "SYNAPSE",
        "TABLEAU",
        "TALEND",
        "THOUGHTSPOT",
        "UNKNOWN",
        "YELLOWBRICK",
    ]
    statuses = PlatformTypes.get_platform_types()
    assert statuses.sort() == expected_list.sort()


def test_is_platform_type():
    assert PlatformTypes.is_platform_type("SQL_SERVER")


def test_not_is_platform_type():
    assert not PlatformTypes.is_platform_type("FOO")



from pantomath_sdk import JobDidNotRunAtMethods


def test_get_job_did_not_run_at_method():
    expected_list = ["TRIGGER_TYPE", "NEXT_RUN_AT"]
    statuses = JobDidNotRunAtMethods.get_job_did_not_run_at_method()
    assert statuses.sort() == expected_list.sort()


def test_is_job_did_not_run_at_method():
    assert JobDidNotRunAtMethods.is_job_did_not_run_at_method("NEXT_RUN_AT")


def test_not_is_job_did_not_run_at_method():
    assert not JobDidNotRunAtMethods.is_job_did_not_run_at_method("FOO")



from pantomath_sdk import AstroDag, PlatformTypes, Asset, AssetPathTypes


def test_astro_dag_good():
    node = AstroDag(
        host_name="https://testing.dev/astro_dags/",
        name="Astro Unit Test",
    )
    assert node.get_name() == "Astro Unit Test"
    assert node.get_type() == "DAG"
    assert (
        node.get_fully_qualified_object_name()
        == "https%3a//testing.dev/astro_dags//astro%20unit%20test"
    )
    assert node.get_platform_type() == PlatformTypes.ASTRO.value
    assert (
        node.get_asset_path().__str__()
        == '[{"depth": 0, "name": "ASTRONOMER", "type": "PLATFORM"}, {"depth": 1, "name": "https://testing.dev/astro_dags/", "type": "CONNECTION"}]'
    )


def test_custom_astro_dag_asset_path():
    node = AstroDag(
        host_name="https://testing.dev/astro_dags/",
        name="Astro Unit Test",
        assets=[
            Asset(name="Organization A", type=AssetPathTypes.ORGANIZATION.value),
            Asset(name="Container A", type=AssetPathTypes.CONTAINER.value),
        ],
    )
    # noqa
    assert (
        node.get_asset_path().__str__()
        == '[{"depth": 0, "name": "ASTRONOMER", "type": "PLATFORM"}, {"depth": 1, "name": "https://testing.dev/astro_dags/", "type": "CONNECTION"}, {"depth": 2, "name": "Organization A", "type": "ORGANIZATION"}, {"depth": 3, "name": "Container A", "type": "CONTAINER"}]'
    )



from pantomath_sdk import ObjectType


def test_get_object_types():
    expected_list = [
        "SQL_TABLE",
        "SQL_VIEW",
        "SQL_MATERIALIZED_VIEW",
        "SQL_FUNCTION",
        "SQL_PROCEDURE",
        "S3_BUCKET",
        "TABLEAU_EXTRACT_REFRESH_TASK",
        "TABLEAU_WORKBOOK",
        "TABLEAU_DATASOURCE",
        "SNOWFLAKE_PIPE",
        "FIVETRAN_CONNECTOR",
        "UNKNOWN",
        "DBT_MODEL",
        "POWER_BI_DASHBOARD",
        "POWER_BI_REPORT",
        "POWER_BI_DATASET",
        "POWER_BI_DATAFLOW_ENTITY",
        "POWER_BI_REFRESH",
        "POWER_BI_DATAFLOW",
        "POWER_BI_ACTIVITY",
        "ADF_ACTIVITY",
        "ADF_DATA_FLOW",
        "ADF_PIPELINE",
        "ADF_DATASET",
        "SYNAPSE_DATAFLOW",
        "PACKAGE",
        "COMPONENT",
        "JOB",
        "DATASOURCE",
        "DATASET",
        "DATAFLOW",
        "ACTIVITY",
        "PIPELINE",
        "REPORT",
        "TRIGGER",
        "REFRESH",
        "TASK",
    ]
    statuses = ObjectType.get_object_types()
    assert statuses.sort() == expected_list.sort()


def test_is_object_type():
    assert ObjectType.is_object_type("SQL_FUNCTION")


def test_not_is_object_type():
    assert not ObjectType.is_object_type("FOO")



from pantomath_sdk.enums.data_volume_object_type import *
from pantomath_sdk.enums.dataset_type import *
from pantomath_sdk.enums.job_did_not_run_at_method import *
from pantomath_sdk.enums.job_object_type import *
from pantomath_sdk.enums.job_run_log_status import *
from pantomath_sdk.enums.job_trigger_type import *
from pantomath_sdk.enums.job_type import *
from pantomath_sdk.enums.object_type import *
from pantomath_sdk.enums.platform_types import *
from pantomath_sdk.enums.asset_path import *
